resolver

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 5, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ResolvedEdge

type ResolvedEdge struct {
	CallerName      string
	CalleeName      string
	CallSiteOffset  int
	CallerStartLine int
	CalleeStartLine int
	CallLine        int
	Weight          int64
	Warnings        []string
}

ResolvedEdge is a fully resolved call edge ready for profile generation.

func Resolve

func Resolve(patterns []string) ([]ResolvedEdge, error)

Resolve takes package patterns, loads them with full type info, finds directives, and resolves caller/callee linker symbols.

Jump to